@@ -1,4 +1,4 @@
-#define IMAGES_DIR "/usr/local/share/pixmaps/"
+#define IMAGES_DIR "/usr/share/pixmaps/"
 GtkWidget *main_window, *vbox1;
 GtkWidget *table1;
 GtkWidget *buttons[15];
